0.9.9 API documentation: bit.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
bit.hpp File Reference

GLM_GTX_bit More...

Go to the source code of this file.

## Functions
template<typename genIUType >
GLM_FUNC_DECL genIUType | highestBitValue (genIUType Value)
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | highestBitValue (vec< L, T, Q > const &value)
| Find the highest bit set to 1 in a integer variable and return its value. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | lowestBitValue (genIUType Value)
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoAbove (genIUType Value)
| Return the power of two number which value is just higher the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoAbove (vec< L, T, Q > const &value)
| Return the power of two number which value is just higher the input value. More...
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoBelow (genIUType Value)
| Return the power of two number which value is just lower the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoBelow (vec< L, T, Q > const &value)
| Return the power of two number which value is just lower the input value. More...
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoNearest (genIUType Value)
| Return the power of two number which value is the closet to the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoNearest (vec< L, T, Q > const &value)
| Return the power of two number which value is the closet to the input value. More...

## Detailed Description

GLM_GTX_bit

See also
  Core features (dependence)

Definition in file bit.hpp.